import { ConfigurationService } from '../configuration/configuration.service';
import { LoggerService } from '../logger/services/logger.service';
import { Filter } from './models/filter';
import * as i0 from "@angular/core";
/**
 * Allows access to filters defined in nae.json during runtime.
 *
 * Filters are always returned as copies to avoid unintended side effects when operating on them.
 *
 * Also see {@link Filter}.
 */
export declare class FilterRepository {
    protected _configService: ConfigurationService;
    protected _log: LoggerService;
    /**
     * Stores the filters managed by the repository. Keys are filterIds.
     */
    protected _filters: Map<string, Filter>;
    /**
     * Loads and creates filters declared in nae.json.
     */
    constructor(_configService: ConfigurationService, _log: LoggerService);
    /**
     * Logs a warning if filter with the given id already exists. The warning states that the filter will be replaced.
     * @param filterId ID of the filter who's existence should be checked
     */
    protected warnIfFilterExists(filterId: string): void;
    /**
     * @param filterId ID of the filter that should be retrieved
     * @returns a copy of the specified filter, or `undefined` if such filter doesn't exist in the repository.
     */
    getFilter(filterId: string): Filter | undefined;
    /**
     * Stores a new filter into the repository. If the repository already contains a filter with the same ID, the stored filter
     * will be replaced and a warning will be logged.
     *
     * The repository stores a copy of the provided filter, to ensure that the objects in the repository aren't referenced from outside.
     * @param filter the filter that should be stored
     */
    saveFilter(filter: Filter): void;
    /**
     * @returns list of case filter identifiers stored in the repository
     */
    getCaseFilterList(): Array<string>;
    /**
     * @returns list of task filter identifiers stored in the repository
     */
    getTaskFilterList(): Array<string>;
    /**
     * @param predicate condition that must be fulfilled by the filters in the repository in order to be included in the result
     * @returns list of filter identifiers that fulfill the given predicate
     */
    protected getFilterList(predicate: (f: Filter) => boolean): Array<string>;
    /**
     * @param filterIds list of ids of filters that should be returned
     * @returns list of copies of specified filters. If some of the filters don't exist in the repository, they won't be included
     * and the array will contain less elements than the input array.
     */
    getFilters(filterIds: Array<string>): Array<Filter>;
    /**
     * Removes all stored filters from the repository
     */
    removeAllFilters(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterRepository, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterRepository>;
}
