import { EventEmitter, OnDestroy } from '@angular/core';
import { FormSubmitEvent, HasForm } from '../has-form';
import { FormGroup } from '@angular/forms';
import { MessageResource } from '../../resources/interface/message-resource';
import { LoadingEmitter } from '../../utility/loading-emitter';
import { SignUpService } from '../../authentication/sign-up/services/sign-up.service';
import { LoggerService } from '../../logger/services/logger.service';
import { UserRegistrationRequest } from '../../authentication/sign-up/models/user-registration-request';
import { Observable } from 'rxjs';
import { TranslateService } from '@ngx-translate/core';
import * as i0 from "@angular/core";
/**
 * Holds the logic that is shared between `RegistrationFormComponent` and `ForgottenPasswordFormComponent`.
 */
export declare abstract class AbstractRegistrationComponent implements HasForm, OnDestroy {
    protected _signupService: SignUpService;
    protected _log: LoggerService;
    protected _translate: TranslateService;
    protected minPasswordLength: number | undefined;
    rootFormGroup: FormGroup;
    hidePassword: boolean;
    hideRepeatPassword: boolean;
    formSubmit: EventEmitter<FormSubmitEvent>;
    register: EventEmitter<MessageResource>;
    /**
     * Emits whenever the provided token gets resolved as invalid
     */
    invalidToken: EventEmitter<void>;
    private _token;
    private _tokenVerified;
    loadingToken: LoadingEmitter;
    loadingSubmit: LoadingEmitter;
    userEmail: string;
    protected constructor(_signupService: SignUpService, _log: LoggerService, _translate: TranslateService, minPasswordLength: number | undefined);
    ngOnDestroy(): void;
    set token(token: string);
    get token(): string;
    get tokenVerified(): boolean;
    onSubmit(): void;
    isFieldValid(formControlName: string): boolean;
    getErrorMessage(formControlName: string): string;
    protected abstract createRequestBody(): UserRegistrationRequest;
    protected abstract callRegistration(requestBody: UserRegistrationRequest): Observable<MessageResource>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractRegistrationComponent, [null, null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AbstractRegistrationComponent, "ncc-abstract-registration", never, { "token": { "alias": "token"; "required": false; }; }, { "formSubmit": "formSubmit"; "register": "register"; "invalidToken": "invalidToken"; }, never, never, false, never>;
}
