import { Type } from '@angular/core';
import { Categories } from '../models/category/categories';
import { Category } from '../models/category/category';
import { CategorySerialisationPair } from './category-serialisation-pair';
import * as i0 from "@angular/core";
/**
 * A service that resolves {@link Categories} (or custom string) into a concrete {@link Category} implementation class and vice versa.
 */
export declare class CategoryResolverService {
    private readonly _classToStringTable;
    private readonly _stringToClassTable;
    constructor();
    /**
     * Registers the default class - serialisation pairings for all the {@link Category} classes provided by this library.
     */
    private registerDefaultPairings;
    /**
     * Resolves the categories from the {@link Categories} enum into their corresponding classes.
     * Passes all unresolved values into the [toCustomClass()]{@link CategoryResolverService#toCustomClass} method - this
     * behavior is deprecated in 5.6.0.
     * @param category a serialized representation of the {@link Category} class
     */
    toClass(category: Categories | string): Type<Category<any>> | undefined;
    /**
     * Resolves a {@link Category} class or a class instance into its corresponding serialisation.
     * @param category a class reference or a class instance
     * @returns the associated serialisation or `undefined` if no serialisation was associated
     */
    serialize(category: Type<Category<any>> | Category<any>): Categories | string | undefined;
    /**
     * Should resolve any custom categories into their corresponding class objects.
     *
     * If you implement any custom {@link Category} classes, you should override this method to resolve them after serialization.
     *
     * @param category the serialized string provided by your [Category.serialize()]{@link Category#serializeClass} implementation
     * @returns `undefined`
     *
     * @deprecated in 5.6.0 - use the [registerPair]{@link CategoryResolverService#registerPair} method to register
     * both transformations instead.
     */
    protected toCustomClass(category: string): Type<Category<any>> | undefined;
    /**
     * Adds the given mapping to the look-up tables
     *
     * @returns a new pair where: The class is the previous string association. The string is the previous class association.
     * One or both of the values in the returned pair may be `undefined`.
     */
    protected registerPair(pair: CategorySerialisationPair): CategorySerialisationPair;
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryResolverService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CategoryResolverService>;
}
