import { Category } from '../models/category/category';
import { CategoryFactory } from './category-factory';
/**
 * Creates the default case search categories.
 *
 * Depends on {@link CategoryFactory}.
 *
 * The created categories cannot be used to generate any predicates, as their inner state is preemptively destroyed to avoid memory leaks
 * caused by uncompleted Subjects. They should only be used to create new Category instances with the help of the
 * [duplicate()]{@link Category#duplicate} method.
 *
 * @returns an Array containing the default case search categories: {@link CaseDataset}, {@link CaseTitle}, {@link CaseCreationDate},
 * {@link CaseProcess}, {@link CaseTask}, {@link CaseAuthor}, {@link CaseVisualId} and {@link CaseStringId}
 *
 * @deprecated in 5.6.0 - Use the {@link NAE_DEFAULT_CASE_SEARCH_CATEGORIES} injection token instead
 */
export declare function defaultCaseSearchCategoriesFactory(factory: CategoryFactory): Array<Category<any>>;
/**
 * Creates the default task search categories.
 *
 * Depends on {@link CategoryFactory}.
 *
 * The created categories cannot be used to generate any predicates, as their inner state is preemptively destroyed to avoid memory leaks
 * caused by uncompleted Subjects. They should only be used to create new Category instances with the help of the
 * [duplicate()]{@link Category#duplicate} method.
 *
 * @returns an Array containing the default task search categories: {@link TaskAssignee}, {@link TaskTask}, {@link TaskProcess}
 * and {@link TaskRole}
 *
 * @deprecated in 5.6.0 - Use the {@link NAE_DEFAULT_TASK_SEARCH_CATEGORIES} injection token instead
 */
export declare function defaultTaskSearchCategoriesFactory(factory: CategoryFactory): Array<Category<any>>;
