import { OperatorService } from '../../../operator-service/operator.service';
import { LoggerService } from '../../../../logger/services/logger.service';
import { Operator } from '../../operator/operator';
import { Query } from '../../query/query';
import { OptionalDependencies } from '../../../category-factory/optional-dependencies';
import { SearchInputType } from '../search-input-type';
import { SearchAutocompleteOption } from '../search-autocomplete-option';
import { CaseProcess } from './case-process';
import { BehaviorSubject, Observable } from 'rxjs';
import { Category } from '../category';
import { AutocompleteOptions } from '../autocomplete-options';
import { ConfigurationInput } from '../../configuration-input';
import { Categories } from '../categories';
import { FormControl } from '@angular/forms';
import { CategoryMetadataConfiguration } from '../../persistance/generator-metadata';
import { FilterTextSegment } from '../../persistance/filter-text-segment';
interface Datafield {
    netIdentifier: string;
    fieldId: string;
    fieldType: string;
}
export declare class CaseDataset extends Category<Datafield> implements AutocompleteOptions {
    protected _optionalDependencies: OptionalDependencies;
    private static readonly _i18n;
    protected static DISABLED_TYPES: string[];
    protected static readonly DATAFIELD_METADATA = "datafield";
    private static readonly AUTOCOMPLETE_ICON;
    protected readonly _DATAFIELD_INPUT: ConfigurationInput;
    protected _processCategory: CaseProcess;
    protected _configurationInputs$: BehaviorSubject<Array<ConfigurationInput>>;
    protected _datafieldOptions: Map<string, Array<Datafield>>;
    private _datafieldOptionsInitialized$;
    private _allowedNetsSub;
    private _userAutocomplete;
    static FieldTypeToInputType(fieldType: string): SearchInputType;
    constructor(operators: OperatorService, logger: LoggerService, _optionalDependencies: OptionalDependencies);
    destroy(): void;
    get configurationInputs$(): Observable<Array<ConfigurationInput>>;
    get inputType(): SearchInputType;
    /**
     * The allowed operators are dependant on the selected data field.
     *
     * Beware that if you want to change the order of the allowed operators, then you must also update the
     * [selectDefaultOperator()]{@link Category#selectDefaultOperator} method, so that default operator for each data field type matches
     * the default operator of the {@link CaseSimpleDataset} search category. Otherwise the transition of header search into the search GUI
     * won't work properly.
     */
    get allowedOperators(): Array<Operator<any>>;
    /**
     * @returns `CaseDataset` category is not displayed in bold for better readability
     */
    get displayBold(): boolean;
    get hasSelectedDatafields(): boolean;
    protected get _selectedDatafields(): Array<Datafield>;
    reset(): void;
    duplicate(): CaseDataset;
    protected get elasticKeywords(): Array<string>;
    protected resolveElasticKeyword(datafield: Datafield): string;
    get inputPlaceholder(): string;
    protected get datafieldOptionsInitialized$(): Observable<void>;
    protected generateQuery(userInput: Array<unknown>): Query;
    protected standardQueryGenerationStrategy(datafield: Datafield, userInput: Array<unknown>, escapeInput?: boolean): Query;
    protected isNullOperatorQueryGenerationStrategy(datafield: Datafield): Query;
    protected generateNetConstraint(datafield: Datafield): Query;
    protected createDatafieldOptions(): void;
    filterOptions(userInput: Observable<string | SearchAutocompleteOption<Array<string>>>): Observable<Array<SearchAutocompleteOption<Array<string>>>>;
    selectDatafields(datafieldMapKey: string, selectDefaultOperator?: boolean): void;
    /**
     * Adds a new entry or pushes value into an existing entry.
     * When a new entry is created, it is created as an Array of one element.
     * @param key where in the map should the value be added
     * @param value the value that should be added to the map
     */
    protected addToDatafieldOptionsMap(key: string, value: Datafield): void;
    protected isOperandValueSelected(newValue: any): boolean;
    /**
     * Performs a transformation of the `FormControl` value before passing it into the selected `Operator` for query generation.
     * It is mostly useful only for AutocompleteCategories, where the selected value of the FormControl is an object.
     *
     * @param value the FormControlValue
     * @returns If the selected data field has input type `AUTOCOMPLETE` then returns the {@link SearchAutocompleteOption} `value`
     * attribute. Otherwise performs an identity operation.
     */
    protected transformCategoryValue(value: any): any;
    serializeClass(): Categories | string;
    protected serializeOperandValue(valueFormControl: FormControl): unknown;
    protected createMetadataConfiguration(): CategoryMetadataConfiguration;
    protected loadConfigurationFromMetadata(configuration: CategoryMetadataConfiguration): Observable<void>;
    protected deserializeOperandValue(value: unknown): Observable<any>;
    protected createConfigurationFilterTextSegments(): Array<FilterTextSegment>;
}
export {};
