import { OperatorService } from '../../../operator-service/operator.service';
import { LoggerService } from '../../../../logger/services/logger.service';
import { Query } from '../../query/query';
import { Operator } from '../../operator/operator';
import { CaseProcess } from './case-process';
import { OptionalDependencies } from '../../../category-factory/optional-dependencies';
import { NoConfigurationCategory } from '../no-configuration-category';
import { CaseDataset } from './case-dataset';
import { Categories } from '../categories';
import { CategoryGeneratorMetadata } from '../../persistance/generator-metadata';
import { Observable } from 'rxjs';
/**
 * This class aims to be a simpler more limited version of the {@link CaseDataset} {@link Category} implementation.
 *
 * It can only generate "equality" queries for a single field. The category must be configured before it can be used to generate queries.
 *
 * This category cannot be serialized. If you want to preserve this category's state convert it to {@link CaseDataset}
 * with the [transformToCaseDataset()]{@link CaseSimpleDataset#transformToCaseDataset} method and serialize the result.
 *
 * See [configure]{@link CaseSimpleDataset#configure} for more information.
 */
export declare class CaseSimpleDataset extends NoConfigurationCategory<string> {
    protected _optionalDependencies: OptionalDependencies;
    private static readonly _i18n;
    protected _fieldId: string;
    protected _fieldType: string;
    protected _netIdentifiers: Array<string>;
    protected _elasticKeyword: string;
    protected _processCategory: CaseProcess;
    constructor(operators: OperatorService, logger: LoggerService, _optionalDependencies: OptionalDependencies);
    destroy(): void;
    get inputPlaceholder(): string;
    configure(fieldId: string, fieldType: string, netIdentifiers: Array<string>): void;
    protected resolveElasticKeyword(): void;
    protected get elasticKeywords(): Array<string>;
    get selectedOperator(): Operator<any>;
    duplicate(): CaseSimpleDataset;
    /**
     * Creates a {@link CaseDataset} instance and configures it so, that the query it generates targets
     * the selected field, uses the default operator and its operands are what the user provided.
     *
     * @param fieldType the type of the field that should be targeted by the transformed Category
     * @param fieldTitle the title of the field that should be targeted by the transformed Category
     * @param userInput the operands for the queried field
     * @returns a new {@link CaseDataset} configured with the provided values
     */
    transformToCaseDataset(fieldType: string, fieldTitle: string, userInput: Array<any>): CaseDataset;
    protected generateQuery(userInput: Array<unknown>): Query;
    serializeClass(): Categories | string;
    /**
     * Serialization is not supported. Throws an error.
     */
    createMetadata(): never;
    /**
     * Deserialization is not supported. Throws an error.
     */
    loadFromMetadata(metadata: CategoryGeneratorMetadata): Observable<void>;
}
