import { OnDestroy } from '@angular/core';
import { SideMenuControl } from '../../models/side-menu-control';
import { FilterRepository } from '../../../filter/filter.repository';
import { Filter } from '../../../filter/models/filter';
import { FilteredArray } from './model/filtered-array';
import { FormControl } from '@angular/forms';
import { MatSelectionList, MatSelectionListChange } from '@angular/material/list';
import { Subscription } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Allows user to choose a {@link Filter} from the {@link FilterRepository}.
 *
 * Publishes events to the {@link SideMenuControl} object when:
 *
 * - filter is selected by the user. Message: `New selected filter`, Data: is either the selected filter or `undefined` if the user
 * deselected the filter
 *
 * - filter selection is confirmed by the user. Message: `Selected filter was confirmed`, Data: the selected filter. If the user didn't
 * select any filter this event will not be published.
 *
 */
export declare abstract class AbstractFilterSelectorComponent implements OnDestroy {
    protected _sideMenuControl: SideMenuControl;
    protected _filterRepository: FilterRepository;
    /**
     * @ignore
     * Case filters bound to HTML
     */
    caseFilters: FilteredArray<Filter>;
    /**
     * @ignore
     * Task filters bound to html
     */
    taskFilters: FilteredArray<Filter>;
    /**
     * @ignore
     * Task filters bound to html
     */
    protected subValue: Subscription;
    /**
     * @ignore
     * `FormControl` for the search input
     */
    searchFormControl: FormControl;
    /**
     * @ignore
     * Currently selected filter. `undefined` if no filter is selected.
     */
    protected _selectedFilter: Filter;
    /**
     * @ignore
     * Reference to the `mat-selection-list` component, that holds the list of case filters.
     */
    caseFilterList: MatSelectionList;
    /**
     * @ignore
     * Reference to the `mat-selection-list` component, that holds the list of task filters.
     */
    taskFilterList: MatSelectionList;
    /**
     * @ignore
     * Stores the predicate used for filtering of filters with {@linkFilteredArray}.
     * @param item some filter from the list
     * @param searchInput value the user is searching for
     */
    protected _filterPredicate: (item: Filter, searchInput: string) => boolean;
    /**
     * Retrieves the {@link Filter} objects from the {@link FilterRepository} and instantiates this component.
     *
     * Filters that are available for selection can be set using the injected data. See {@link FilterSelectorInjectionData}
     * for more information.
     * @param _sideMenuControl -
     * @param _filterRepository -
     */
    constructor(_sideMenuControl: SideMenuControl, _filterRepository: FilterRepository);
    ngOnDestroy(): void;
    /**
     * @ignore
     * Changes the currently selected filter and publishes an event about this to the output stream in {@link SideMenuControl}.
     * @param filter the newly selected filter
     */
    filterSelected(filter: Filter): void;
    /**
     * @ignore
     * Closes the side menu and publishes an event with the currently selected filter.
     */
    filterSelectionConfirmed(): void;
    /**
     * @ignore
     * Clears selection of task filters and ensures that only one case filter can be selected at once.
     * @param event list change event published byt the material component
     */
    caseFilterSelected(event: MatSelectionListChange): void;
    /**
     * @ignore
     * Clears selection of case filters and ensures that only one task filter can be selected at once.
     * @param event list change event published byt the material component
     */
    taskFilterSelected(event: MatSelectionListChange): void;
    /**
     * @ignore
     * Filters both lists of filters based on user search input.
     * @param newValue user search input value
     */
    filterFilters(newValue: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<AbstractFilterSelectorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AbstractFilterSelectorComponent, "ncc-abstract-filter-selector", never, {}, {}, never, never, false, never>;
}
