import { HttpParams } from '@angular/common/http';
import { Observable } from 'rxjs';
import { Page } from '../../../resources/interface/page';
/**
 * A utility class that mock any pageable endpoint that takes one parameter
 */
export declare class MockEndpoint {
    /**
     * The content that is queries by the requests.
     */
    content: Array<string>;
    /**
     * @param filter - a filtering argument. This mock ignores it.
     * @param params - pagination configuration. The mock extracts the `size` and `page` property to format the result properly.
     * @returns an `Observable` containing a properly formatted {@link Page} object.
     *
     * The `pagination` attributes are filled according to the request and the endpoints [content]{@link MockEndpoint#content}.
     *
     * If an empty {@link Page} should be returned the returned object has its `content` attribute set to some object
     * (to match backend and resource service behavior).
     * Otherwise the `content` attribute contains the corresponding subsection fo the [content]{@link MockEndpoint#content} array.
     */
    search(filter: unknown, params: HttpParams): Observable<Page<unknown>>;
    private getPagination;
}
