import { GridLayout } from '../../grid-layout/model/grid-element';
import { BooleanField } from '../../../data-fields/boolean-field/models/boolean-field';
import { ButtonField } from '../../../data-fields/button-field/models/button-field';
import { IncrementingCounter } from '../../incrementing-counter';
import { TaskRefField } from '../../../data-fields/task-ref-field/model/task-ref-field';
import { FieldTypeResource } from '../../../task-content/model/field-type-resource';
/**
 * Creates a mock boolean or button field, with the specified properties
 * @param visible if `true` the fields behavior is set to `editable`, if `false` the fields behavior is set to `hidden`
 * @param layout position of the field in the grid layout
 * @param counterOrStringId if a `string` is provided its value will be used as the fields ID.
 * If a number is provided the fields ID will be set to 'f<number>'.
 * If an {@link IncrementingCounter} is provided the ID will follow the same pattern as for the `number` argument,
 * but the counter will be used to generate the number.
 * @param fieldType determines what type of field should be generated.
 * Currently only `boolean`, `button` and `task ref` fields are supported. If an unsupported field type is used an error is thrown.
 * @param taskRefValue determines the value of the task ref field if a task ref field is generated
 */
export declare function createMockField(visible?: boolean, layout?: GridLayout, counterOrStringId?: number | IncrementingCounter | string, fieldType?: FieldTypeResource.BOOLEAN | FieldTypeResource.BUTTON | FieldTypeResource.TASK_REF, taskRefValue?: Array<string>): BooleanField | ButtonField | TaskRefField;
