import { OnDestroy } from '@angular/core';
import { AbstractSortableViewComponent } from '../abstract/sortable-view';
import { PetriNetResourceService } from '../../resources/engine-endpoint/petri-net-resource.service';
import { BehaviorSubject, Observable } from 'rxjs';
import { Net } from '../../process/net';
import { LoggerService } from '../../logger/services/logger.service';
import { HttpParams } from '@angular/common/http';
import { Pagination } from '../../resources/interface/pagination';
import { LoadingEmitter } from '../../utility/loading-emitter';
import { ListRange } from '@angular/cdk/collections';
import { PetriNetRequestBody } from '../../resources/interface/petri-net-request-body';
import { DialogService } from '../../dialog/services/dialog.service';
import { SnackBarService } from '../../snack-bar/services/snack-bar.service';
import { TranslateService } from '@ngx-translate/core';
import { SearchIndexResolverService } from '../../search/search-keyword-resolver-service/search-index-resolver.service';
import * as i0 from "@angular/core";
export declare class WorkflowViewService extends AbstractSortableViewComponent implements OnDestroy {
    protected _petriNetResource: PetriNetResourceService;
    protected _log: LoggerService;
    protected _dialogService: DialogService;
    protected _snackBarService: SnackBarService;
    protected _translate: TranslateService;
    protected _loading$: LoadingEmitter;
    protected _workflows$: Observable<Array<Net>>;
    protected _clear: boolean;
    protected _nextPage$: BehaviorSubject<Pagination>;
    protected _endOfData: boolean;
    protected _pagination: Pagination;
    protected _baseFilter: PetriNetRequestBody;
    protected _showDeleteConfirmationDialog: boolean;
    constructor(_petriNetResource: PetriNetResourceService, _log: LoggerService, _dialogService: DialogService, _snackBarService: SnackBarService, _translate: TranslateService, resolver: SearchIndexResolverService, injectedBaseFilter: PetriNetRequestBody, confirmDelete: boolean);
    ngOnDestroy(): void;
    get loading(): boolean;
    get loading$(): Observable<boolean>;
    get workflows$(): Observable<Array<Net>>;
    loadPage(pageRequest: Pagination): Observable<Array<Net>>;
    nextPage(renderedRange: ListRange, totalLoaded: number, pagination?: Pagination): void;
    reload(): void;
    /**
     * Opens a dialog (if configured) and then asks the service to delete the selected workflow.
     * @param workflow the workflow that should be deleted
     */
    deleteWorkflow(workflow: Net): void;
    /**
     * Sends the workflow delete to backend and processes the result.
     * @param workflow the workflow that should be deleted
     */
    protected _deleteWorkflow(workflow: Net): void;
    protected getMetaFieldSortId(): string;
    protected getDefaultSortParam(): string;
    protected addPageParams(params: HttpParams, pagination: Pagination): HttpParams;
    static ɵfac: i0.ɵɵFactoryDeclaration<WorkflowViewService, [null, null, null, null, null, null, { optional: true; }, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<WorkflowViewService>;
}
